/*
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 * 
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.ste.tmc.konfiguration;

import de.bsvrz.dav.daf.main.config.SystemObject;
import de.bsvrz.sys.funclib.debug.Debug;

/**
 * Es wird ein Messquerschnitt modelliert.
 * 
 * 
 * Erstellt auf Basis der SWE RDS/TMC von: Dambach Werke GmbH, Stefan Sans
 * 
 * @since 07/2016: Adaptiert für TMC-Meldungen durch: BitCtrl Systems GmbH
 * @author BitCtrl Systems GmbH, Gieseler
 */
public class MessQuerschnitt extends DavProxyObjekt {
	/**
	 * Debug-Logger für Logging-Ausgaben.
	 */
	private final static Debug _debug = Debug.getLogger();

	/**
	 * Strassensegment, auf dem dieser Messquerschnitt liegt.
	 */
	private StrassenSegment _segment;

	/**
	 * Offset - Abstand vom Anfang in m - dieses MQs auf seinem Strassensegment.
	 */
	private long _offset;

	/**
	 * Erstellt eine neue Instanz vom Typ <code>MessQuerschnitt</code>.
	 * 
	 * @param davObjekt
	 *            das zuzuordnente Dav-Objekt
	 * @param segment
	 *            Strassensegment, auf dem dieser Messquerschnitt liegt
	 * @param offset
	 *            Offset - Abstand vom Anfang in m - dieses MQs auf seinem
	 *            Strassensegment
	 */
	public MessQuerschnitt(SystemObject davObjekt, StrassenSegment segment, long offset) {
		super(davObjekt);
		_segment = segment;
		_offset = offset;
	}

	/**
	 * @return das Strassensegment, auf dem dieser Messquerschnitt liegt
	 */
	public StrassenSegment getSegment() {
		return _segment;
	}

	/**
	 * @return den Offset - Abstand vom Anfang in m - dieses Mqs auf seinem
	 *         Strassensegment
	 */
	public long getOffset() {
		return _offset;
	}

}
